Struct windsh_core::logs::Log [−][src]
pub struct Log { /* fields omitted */ }this is the structure that a log should have, this is global for any level we can use them as follows:
use windsh_core::logs::{Log, LogLevel}; // this print a log Log::new(LogLevel::Warning, 0, "This is a test log.").show(); // this return a log let my_log: Log = Log::new(LogLevel::Warning, 0, "This is a test log."); // we can also print an existing log my_log.show();
these are some uses that this structure can be given.
Implementations
impl Log[src]
pub fn new(level: LogLevel, code: u16, message: &str) -> Self[src]
This function allows us to create a new log in a very intuitive and easy way, it also allows us to do extra things like print it in the console
pub fn show(&self)[src]
pub fn set_level(&mut self, level: LogLevel)[src]
pub fn set_code(&mut self, code: u16)[src]
pub fn set_message(&mut self, message: &str)[src]
pub fn get_level(&self) -> LogLevel[src]
pub fn get_code(&self) -> u16[src]
pub fn get_message(&self) -> String[src]